==> ario-1.3.tar.gz: ario-1.3/src/ario-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "ario-enum-types.h"

/* enumerations from "servers/ario-server.h" */
#include "servers/ario-server.h"

GType
ario_server_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ ArioServerMpd,
			  "ArioServerMpd",
			  "mpd" },
			{ ArioServerXmms,
			  "ArioServerXmms",
			  "xmms" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("ArioServerType"),
				values);
	}
	return the_type;
}

GType
ario_server_action_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ ARIO_SERVER_ACTION_ADD,
			  "ARIO_SERVER_ACTION_ADD",
			  "add" },
			{ ARIO_SERVER_ACTION_DELETE_ID,
			  "ARIO_SERVER_ACTION_DELETE_ID",
			  "delete-id" },
			{ ARIO_SERVER_ACTION_DELETE_POS,
			  "ARIO_SERVER_ACTION_DELETE_POS",
			  "delete-pos" },
			{ ARIO_SERVER_ACTION_MOVE,
			  "ARIO_SERVER_ACTION_MOVE",
			  "move" },
			{ ARIO_SERVER_ACTION_MOVEID,
			  "ARIO_SERVER_ACTION_MOVEID",
			  "moveid" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("ArioServerActionType"),
				values);
	}
	return the_type;
}

/* enumerations from "shell/ario-shell.h" */
#include "shell/ario-shell.h"

GType
ario_visibility_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ VISIBILITY_HIDDEN,
			  "VISIBILITY_HIDDEN",
			  "hidden" },
			{ VISIBILITY_VISIBLE,
			  "VISIBILITY_VISIBLE",
			  "visible" },
			{ VISIBILITY_TOGGLE,
			  "VISIBILITY_TOGGLE",
			  "toggle" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("ArioVisibility"),
				values);
	}
	return the_type;
}


/* Generated data ends here */

==> ario_1.6.orig.tar.gz: ario-1.6/src/ario-enum-types.c <==

/* Generated data (by glib-mkenums) */

#include "ario-enum-types.h"

/* enumerations from "servers/ario-server.h" */
#include "servers/ario-server.h"

GType
ario_server_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ ArioServerMpd,
			  "ArioServerMpd",
			  "mpd" },
			{ ArioServerXmms,
			  "ArioServerXmms",
			  "xmms" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("ArioServerType"),
				values);
	}
	return the_type;
}

GType
ario_server_action_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ ARIO_SERVER_ACTION_ADD,
			  "ARIO_SERVER_ACTION_ADD",
			  "add" },
			{ ARIO_SERVER_ACTION_DELETE_ID,
			  "ARIO_SERVER_ACTION_DELETE_ID",
			  "delete-id" },
			{ ARIO_SERVER_ACTION_DELETE_POS,
			  "ARIO_SERVER_ACTION_DELETE_POS",
			  "delete-pos" },
			{ ARIO_SERVER_ACTION_MOVE,
			  "ARIO_SERVER_ACTION_MOVE",
			  "move" },
			{ ARIO_SERVER_ACTION_MOVEID,
			  "ARIO_SERVER_ACTION_MOVEID",
			  "moveid" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("ArioServerActionType"),
				values);
	}
	return the_type;
}

/* enumerations from "sources/ario-source-manager.h" */
#include "sources/ario-source-manager.h"

GType
ario_source_type_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ ARIO_SOURCE_BROWSER,
			  "ARIO_SOURCE_BROWSER",
			  "browser" },
			{ ARIO_SOURCE_RADIO,
			  "ARIO_SOURCE_RADIO",
			  "radio" },
			{ ARIO_SOURCE_SEARCH,
			  "ARIO_SOURCE_SEARCH",
			  "search" },
			{ ARIO_SOURCE_PLAYLISTS,
			  "ARIO_SOURCE_PLAYLISTS",
			  "playlists" },
			{ ARIO_SOURCE_FILESYSTEM,
			  "ARIO_SOURCE_FILESYSTEM",
			  "filesystem" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("ArioSourceType"),
				values);
	}
	return the_type;
}

/* enumerations from "shell/ario-shell.h" */
#include "shell/ario-shell.h"

GType
ario_visibility_get_type (void)
{
	static GType the_type = 0;
	
	if (the_type == 0)
	{
		static const GEnumValue values[] = {
			{ VISIBILITY_HIDDEN,
			  "VISIBILITY_HIDDEN",
			  "hidden" },
			{ VISIBILITY_VISIBLE,
			  "VISIBILITY_VISIBLE",
			  "visible" },
			{ VISIBILITY_TOGGLE,
			  "VISIBILITY_TOGGLE",
			  "toggle" },
			{ 0, NULL, NULL }
		};
		the_type = g_enum_register_static (
				g_intern_static_string ("ArioVisibility"),
				values);
	}
	return the_type;
}


/* Generated data ends here */
